pub fn packages_allow_none(expr: &ConditionExpr) -> boolExpand description
Whether expr is package terms only, none of which needs a code
([9P0..1]): a status of that kind requires nothing.
pub fn packages_allow_none(expr: &ConditionExpr) -> boolWhether expr is package terms only, none of which needs a code
([9P0..1]): a status of that kind requires nothing.