pub fn validate_max_integer_digits(value: &str, max: usize) -> ConditionResultExpand description
Validate that a numeric string has at most max integer digits (before decimal point).
Ignores leading minus sign.
pub fn validate_max_integer_digits(value: &str, max: usize) -> ConditionResultValidate that a numeric string has at most max integer digits (before decimal point).
Ignores leading minus sign.