pub fn refuses_presence<E: ConditionEvaluator + ?Sized>(
status: &str,
evaluator: &E,
ctx: &EvaluationContext<'_>,
ub_definitions: &BTreeMap<String, ConditionExpr>,
) -> boolExpand description
Whether something present under status is not allowed where ctx is: a
Muss/X status with a condition that evaluates to false through
PresentTarget. Soll/Kann, an unconditional status, an undecidable
condition, a package ([19P1..1], judged by its own check) and a status of
several lines refuse nothing.